Usage
=====

How to use ``pandas_indexing`` is explained in jupyter notebooks.
You can either view static versions of them below, or download and execute them as
`interactive jupyter notebooks`_.

.. toctree::
   :maxdepth: 2

   notebooks/introduction.ipynb

.. _interactive jupyter notebooks:
   https://github.com/coroa/pandas-indexing/tree/main/docs/notebooks
